package lablgtk3-extras

  1. Overview
  2. Docs

Module Configwin_ihmSource

This module contains the gui functions of Configwin.

Sourceval file_html_config : string
Sourceval debug : bool
Sourceval dbg : string -> unit
Sourceval html_config_file_and_option : unit -> [ `Open ] Ocf.group * Configwin_types.html_binding list Ocf.conf_option

Return the config group for the html config file, and the option for bindings.

Sourceval last_dir : string ref

This variable contains the last directory where the user selected a file.

Sourceval select_files : ?parent:??? -> ?dir:??? -> ?fok:??? -> string -> string list

This function allows the user to select a file and returns the selected file name. An optional function allows to change the behaviour of the ok button. A VOIR : mutli-selection ?

Sourceval select_date : ?parent:??? -> string -> (int * int * int) -> (int * int * int) option

Make the user select a date.

Sourceclass 'a list_selection_box : 'a list ref -> (('a -> string) * string option) list -> string option -> ('a -> 'a) option -> ('a -> string option) -> ('a -> 'a -> bool) -> (unit -> 'a list) -> string -> bool -> object ... end

This class builds a frame with a list and three buttons : one to add items, one to move up selected items, and one to remove the selected items. The class takes in parameter a function used to add items and a list ref which is used to store the content of the list. At last, a title for the frame is also in parameter, so that each instance of the class creates a frame.

This class is used to build a box for a string parameter.

This class is used to build a box for a combo parameter.

Class used to pack a custom box.

This class is used to build a box for a color parameter.

This class is used to build a box for a font parameter.

This class is used to build a box for a text parameter.

This class is used to build a box a html parameter.

This class is used to build a box for a boolean parameter.

This class is used to build a box for a file name parameter.

This class is used to build a box for a hot key parameter.

This class is used to build a box for a date parameter.

Sourceclass 'a list_param_box : 'a Configwin_types.list_param -> object ... end

This class is used to build a box for a parameter whose values are a list.

This class is used to build a box from a configuration structure and adds the page to the given notebook.

Sourceval tabbed_box : Configwin_types.configuration_structure list -> (string * (unit -> unit)) list -> GPack.box

Create a vbox with the list of given configuration structure list, and the given list of buttons (defined by their label and callback). Before calling the callback of a button, the apply function of each parameter is called.

Sourceval edit : ?parent:??? -> ?with_apply:??? -> ?apply:??? -> string -> ?width:??? -> ?height:??? -> Configwin_types.configuration_structure list -> Configwin_types.return_button

This function takes a configuration structure list and creates a window to configure the various parameters.

Sourceval box : Configwin_types.parameter_kind list -> GPack.box * (unit -> unit)

Create a vbox with the list of given parameters.

Sourceval simple_edit : ?parent:??? -> ?with_apply:??? -> ?apply:??? -> string -> ?width:??? -> ?height:??? -> Configwin_types.parameter_kind list -> Configwin_types.return_button

This function takes a list of parameter specifications and creates a window to configure the various parameters.

Sourceval edit_string : string -> string -> string
Sourceval string : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> string -> string -> Configwin_types.parameter_kind

Create a string param.

Sourceval custom_string : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> to_string:('a -> string) -> of_string:(string -> 'a) -> string -> 'a -> Configwin_types.parameter_kind

Create a custom string param.

Sourceval bool : ?editable:??? -> ?help:??? -> ?f:??? -> string -> bool -> Configwin_types.parameter_kind

Create a bool param.

Sourceval list : ?editable:??? -> ?help:??? -> ?f:??? -> ?eq:??? -> ?edit:??? -> ?add:??? -> ?color:??? -> string -> (('a -> string) * string option) list -> 'a list -> Configwin_types.parameter_kind

Create a list param.

Sourceval strings : ?editable:??? -> ?help:??? -> ?f:??? -> ?eq:??? -> ?add:??? -> string -> string list -> Configwin_types.parameter_kind

Create a strings param.

Sourceval color : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> string -> string -> Configwin_types.parameter_kind

Create a color param.

Sourceval font : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> string -> string -> Configwin_types.parameter_kind

Create a font param.

Sourceval combo : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> ?new_allowed:??? -> string -> string list -> string -> Configwin_types.parameter_kind

Create a combo param.

Sourceval text : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> string -> string -> Configwin_types.parameter_kind

Create a text param.

Sourceval custom_text : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> to_string:('a -> string) -> of_string:(string -> 'a) -> string -> 'a -> Configwin_types.parameter_kind

Create a custom text param.

Sourceval html : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> string -> string -> Configwin_types.parameter_kind

Create a html param.

Sourceval filename : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> string -> string -> Configwin_types.parameter_kind

Create a filename param.

Sourceval filenames : ?editable:??? -> ?help:??? -> ?f:??? -> ?eq:??? -> string -> string list -> Configwin_types.parameter_kind

Create a filenames param.

Sourceval date : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> ?f_string:??? -> string -> (int * int * int) -> Configwin_types.parameter_kind

Create a date param.

Sourceval hotkey : ?editable:??? -> ?expand:??? -> ?help:??? -> ?f:??? -> string -> (Gdk.Tags.modifier list * int) -> Configwin_types.parameter_kind

Create a hot key param.

Sourceval custom : ?label:??? -> GPack.box -> (unit -> unit) -> bool -> Configwin_types.parameter_kind

Create a custom param.